@@ -7,11 +7,13 @@
 #include <os.h>
 
 #include <debug.h>
-#include <assert.h>
+#include <hid_assert.h>
 
 hid_return hid_os_force_claim(HIDInterface* const hidif, int const interface,
     HIDInterfaceMatcher const* const matcher, unsigned short retries)
 {
+  retries = retries;
+	
   if (!hidif) {
     ERROR("cannot open NULL HIDInterface.");
     return HID_RET_INVALID_PARAMETER;
