@@ -173,7 +173,8 @@ hid_return hid_open(HIDInterface* const hidif, int const interface,
   }
   NOTICE("successfully claimed USB device %s.", hidif->id);
 
-  hid_prepare_interface(hidif);
+  ret = hid_prepare_interface(hidif);
+  if (ret != HID_RET_SUCCESS) return ret;
 
   NOTICE("successfully opened USB device %s.", hidif->id);
   return HID_RET_SUCCESS;
@@ -218,7 +219,8 @@ hid_return hid_force_open(HIDInterface* const hidif, int const interface,
   }
   NOTICE("successfully claimed USB device %s.", hidif->id);
  
-  hid_prepare_interface(hidif);
+  ret = hid_prepare_interface(hidif);
+  if (ret != HID_RET_SUCCESS) return ret;
 
   NOTICE("successfully opened USB device %s.", hidif->id);
   return HID_RET_SUCCESS;
@@ -273,7 +275,7 @@ bool hid_is_opened(HIDInterface const* hidif)
  * This file is part of libhid, a user-space HID access library.
  * libhid is (c) 2003-2005
  *   Martin F. Krafft <libhid@pobox.madduck.net>
- *   Charles Lepple <clepple@ghz.cc>
+ *   Charles Lepple <clepple+libhid@ghz.cc>
  *   Arnaud Quette <arnaud.quette@free.fr> && <arnaud.quette@mgeups.com>
  * and distributed under the terms of the GNU General Public License.
  * See the file ./COPYING in the source distribution for more information.
