@@ -7,6 +7,11 @@
 #include <debug.h>
 #include <assert.h>
 
+/*! @todo This code does not seem to properly retrieve descriptors for devices
+ * with multiple interfaces. We probably need to parse each interface a little
+ * more to determine which endpoints we want to talk to with usb_control_msg
+ * (EP1IN can't be right for everything).
+ */
 static hid_return hid_prepare_hid_descriptor(HIDInterface* const hidif)
 {
   ASSERT(hid_is_opened(hidif));
@@ -24,7 +29,7 @@ static hid_return hid_prepare_hid_descriptor(HIDInterface* const hidif)
   int len = usb_control_msg(hidif->dev_handle,
       USB_ENDPOINT_IN+1,
       USB_REQ_GET_DESCRIPTOR,
-      (USB_DT_HID << 8) + 0, 0,
+      (USB_DT_HID << 8) + 0, hidif->interface,
       (char*)buffer, BUFLEN,
       USB_TIMEOUT);
 
@@ -44,8 +49,8 @@ static hid_return hid_prepare_hid_descriptor(HIDInterface* const hidif)
    */
   hidif->hid_parser->ReportDescSize = buffer[7] | (buffer[8] << 8);
 
-  NOTICE("successfully initialised HID descriptor for USB device %s.",
-      hidif->id);
+  NOTICE("successfully initialised HID descriptor for USB device %s (%d bytes).",
+      hidif->id, hidif->hid_parser->ReportDescSize);
 
   return HID_RET_SUCCESS;
 }
@@ -69,7 +74,7 @@ static hid_return hid_prepare_report_descriptor(HIDInterface* const hidif)
   int len = usb_control_msg(hidif->dev_handle,
       USB_ENDPOINT_IN+1,
       USB_REQ_GET_DESCRIPTOR,
-      (USB_DT_REPORT << 8) + 0, 0,
+      (USB_DT_REPORT << 8) + 0, hidif->interface,
       (char*)hidif->hid_parser->ReportDesc, hidif->hid_parser->ReportDescSize,
       USB_TIMEOUT);
 
@@ -80,7 +85,7 @@ static hid_return hid_prepare_report_descriptor(HIDInterface* const hidif)
   }
 
   if (len < hidif->hid_parser->ReportDescSize) {
-    WARNING("HID descriptor for USB device %s is too short; "
+    WARNING("HID report descriptor for USB device %s is too short; "
         "expected: %d bytes; got: %d bytes.\n", hidif->id,
         hidif->hid_parser->ReportDescSize, len);
     return HID_RET_REPORT_DESC_SHORT;
